@@ -55,4 +55,26 @@
       (clsql-sys:query "DROP TABLE DUMMY"))
   nil nil)
 
+(deftest :connection/pool/procedure-mysql
+ (unwind-protect
+      (progn
+        (clsql-sys:disconnect)
+        (test-connect :pool t)
+        (clsql-sys:execute-command
+         "CREATE PROCEDURE prTest () BEGIN SELECT 1 \"a\",2 \"b\",3 \"c\" ,4  \"d\" UNION SELECT 5,6,7,8; END;")
+        (clsql-sys:disconnect)
+        (test-connect :pool t)
+        (let ((p0 (clsql-sys:query "CALL prTest();" :flatp t)))
+          (clsql-sys:disconnect)
+          (test-connect :pool t)
+          (let ((p1 (clsql-sys:query "CALL prTest();" :flatp t)))
+            (clsql-sys:disconnect)
+            (test-connect :pool t)
+            (values p0 p1))))
+   (ignore-errors
+    (clsql-sys:execute-command "DROP PROCEDURE prTest;"))
+   (test-connect))
+ ((1 2 3 4) (5 6 7 8))
+ ((1 2 3 4) (5 6 7 8)))
+
 ))
